@@ -3,6 +3,8 @@
 #include <QDebug>
 #include <QKeyEvent>
 
+#include <KI18n/KLocalizedString>
+
 KeysHelper::KeysHelper(QObject *parent)
     : QAbstractListModel(parent)
 {
@@ -39,6 +41,45 @@ KeysHelper::Group KeysHelper::group() const
     return m_group;
 }
 
+QVariantList KeysHelper::signalsGroup() const
+{
+    auto insert = [](const QString &label, const int &signal) -> QVariantMap
+    {
+        return QVariantMap{{"label", label}, {"signal", signal}};
+    };
+
+    QVariantList res;
+
+    int i = 1;
+    res << insert("SIGHUP", i++);
+    res << insert("SIGINT", i++);
+    res << insert("SIGQUIT", i++);
+    res << insert("SIGILL", i++);
+    res << insert("SIGTRAP", i++);
+    res << insert("SIGABRT", i++);
+    ////    res << insert("SIGIOT", i++);
+    res << insert("SIGBUS", i++);
+    res << insert("SIGFPE", i++);
+    res << insert("SIGKILL", i++);
+    res << insert("SIGUSR1", i++);
+    res << insert("SIGEGV", i++);
+    res << insert("SIGUSR2", i++);
+    res << insert("SIGPIPE", i++);
+    res << insert("SIGALRM", i++);
+    res << insert("SIGTERM", i++);
+    res << insert("SIGSTKFLT", i++);
+    res << insert("SIGCHLD", i++);
+    res << insert("SIGCONT", i++);
+    res << insert("SIGSTOP", i++);
+    res << insert("SIGTSTP", i++);
+    res << insert("SIGTTIN", i++);
+    res << insert("SIGTTOU", i++);
+    res << insert("SIGTSTP", i++);
+    res << insert("SIGURG", i++);
+
+    return res;
+}
+
 QHash<int, QByteArray> KeysHelper::roleNames() const
 {
     static QHash<int, QByteArray> roles;
@@ -75,6 +116,10 @@ void KeysHelper::setKeys()
         this->m_keys = defaultKeys();
         break;
     }
+    case Group::SIGNALS_GROUP: {
+        this->m_keys = signalKeys();
+        break;
+    }
     default: {
         this->m_keys = defaultKeys();
     }
@@ -85,7 +130,7 @@ void KeysHelper::setKeys()
     emit this->endResetModel();
 }
 
-QVector<Key> KeysHelper::ctrlKeys() const
+QVector<Key> KeysHelper::ctrlKeys()
 {
     QVector<Key> res;
     res.append({Qt::Key::Key_C, "Ctrl+C", "", Qt::Modifier::CTRL});
@@ -97,7 +142,7 @@ QVector<Key> KeysHelper::ctrlKeys() const
     return res;
 }
 
-QVector<Key> KeysHelper::fnKeys() const
+QVector<Key> KeysHelper::fnKeys()
 {
     QVector<Key> res;
     res.append({Qt::Key::Key_F1, "F1"});
@@ -116,7 +161,7 @@ QVector<Key> KeysHelper::fnKeys() const
     return res;
 }
 
-QVector<Key> KeysHelper::navKeys() const
+QVector<Key> KeysHelper::navKeys()
 {
     QVector<Key> res;
     res.append({Qt::Key::Key_Up, "↑", "go-up"});
@@ -127,7 +172,7 @@ QVector<Key> KeysHelper::navKeys() const
     return res;
 }
 
-QVector<Key> KeysHelper::nanoKeys() const
+QVector<Key> KeysHelper::nanoKeys()
 {
     QVector<Key> res;
     res.append({Qt::Key::Key_Up, "↑", "go-up"});
@@ -148,7 +193,7 @@ QVector<Key> KeysHelper::nanoKeys() const
     return res;
 }
 
-QVector<Key> KeysHelper::defaultKeys() const
+QVector<Key> KeysHelper::defaultKeys()
 {
     QVector<Key> res;
     res.append({Qt::Key::Key_Up, "↑"});
@@ -162,6 +207,17 @@ QVector<Key> KeysHelper::defaultKeys() const
     return res;
 }
 
+QVector<Key> KeysHelper::signalKeys()
+{
+    QVector<Key> res;
+
+    res.append({Qt::Key::Key_Z, i18n("Pause"), "", Qt::Modifier::CTRL});
+    res.append({Qt::Key::Key_C, i18n("Interrupt"), "", Qt::Modifier::CTRL});
+    res.append({Qt::Key::Key_Backslash, i18n("Kill"), "", Qt::Modifier::CTRL});
+
+    return res;
+}
+
 void KeysHelper::sendKey(const int &index, QObject *object)
 {
     if (index > this->m_keys.count() && index < 0)
