@@ -39,7 +39,10 @@ int main(int argc, char *argv[])
     about.setBugAddress("https://invent.kde.org/maui/station/-/issues");
     about.setOrganizationDomain(STATION_URI);
     about.setProgramLogo(app.windowIcon());
-    about.addComponent("QMLTermWidget");
+
+    about.addCredit("QMLTermWidget");
+    about.addCredit("UBPorts Terminal");
+    about.addCredit("Cutefish Terminal");
 
     KAboutData::setApplicationData(about);
 
@@ -84,7 +87,7 @@ int main(int argc, char *argv[])
             server->openTabs(args, false);
         else
         {
-            server->openTabs({"$HOME"}, false);
+            server->openTabs({"$PWD"}, false);
         }
 
     },
